@@ -16,7 +16,6 @@ describe 'neutron::agents::dhcp' do
       :state_path               => '/var/lib/neutron',
       :resync_interval          => 30,
       :interface_driver         => 'neutron.agent.linux.interface.OVSInterfaceDriver',
-      :dhcp_driver              => 'neutron.agent.linux.dhcp.Dnsmasq',
       :root_helper              => 'sudo neutron-rootwrap /etc/neutron/rootwrap.conf',
       :enable_isolated_metadata => false,
       :enable_metadata_network  => false,
@@ -36,21 +35,18 @@ describe 'neutron::agents::dhcp' do
 
     it { is_expected.to contain_class('neutron::params') }
 
-    it_configures 'dnsmasq dhcp_driver'
-
     it 'configures dhcp_agent.ini' do
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/state_path').with_value(p[:state_path]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/resync_interval').with_value(p[:resync_interval]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/interface_driver').with_value(p[:interface_driver]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/dhcp_domain').with_value('<SERVICE DEFAULT>');
-      is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/dhcp_driver').with_value(p[:dhcp_driver]);
+      is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/dhcp_driver').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/root_helper').with_value(p[:root_helper]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/enable_isolated_metadata').with_value(p[:enable_isolated_metadata]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/force_metadata').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/enable_metadata_network').with_value(p[:enable_metadata_network]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/dhcp_broadcast_reply').with_value('<SERVICE DEFAULT>');
-      is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/ovs_integration_bridge').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_dhcp_agent_config('AGENT/availability_zone').with_value('<SERVICE DEFAULT>');
     end
 
@@ -177,24 +173,6 @@ describe 'neutron::agents::dhcp' do
     end
   end
 
-  shared_examples_for 'dnsmasq dhcp_driver' do
-    it 'installs dnsmasq packages' do
-      if platform_params.has_key?(:dhcp_agent_package)
-        is_expected.to contain_package(platform_params[:dnsmasq_base_package]).with_before(['Package[neutron-dhcp-agent]'])
-        is_expected.to contain_package(platform_params[:dnsmasq_utils_package]).with_before(['Package[neutron-dhcp-agent]'])
-      end
-      is_expected.to contain_package(platform_params[:dnsmasq_base_package]).with(
-        :ensure => 'present',
-        :name   => platform_params[:dnsmasq_base_package]
-      )
-      is_expected.to contain_package(platform_params[:dnsmasq_utils_package]).with(
-        :ensure => 'present',
-        :name   => platform_params[:dnsmasq_utils_package]
-      )
-    end
-  end
-
-
   context 'on Debian platforms' do
     let :facts do
       @default_facts.merge(test_facts.merge({
@@ -203,9 +181,7 @@ describe 'neutron::agents::dhcp' do
     end
 
     let :platform_params do
-      { :dnsmasq_base_package  => 'dnsmasq-base',
-        :dnsmasq_utils_package => 'dnsmasq-utils',
-        :dhcp_agent_package    => 'neutron-dhcp-agent',
+      { :dhcp_agent_package    => 'neutron-dhcp-agent',
         :dhcp_agent_service    => 'neutron-dhcp-agent' }
     end
 
@@ -226,9 +202,7 @@ describe 'neutron::agents::dhcp' do
     end
 
     let :platform_params do
-      { :dnsmasq_base_package  => 'dnsmasq',
-        :dnsmasq_utils_package => 'dnsmasq-utils',
-        :dhcp_agent_service    => 'neutron-dhcp-agent' }
+      { :dhcp_agent_service    => 'neutron-dhcp-agent' }
     end
 
     it_configures 'neutron dhcp agent'
