@@ -6,10 +6,16 @@ describe 'neutron::db::sync' do
 
     it 'runs neutron-db-sync' do
       is_expected.to contain_exec('neutron-db-sync').with(
-        :command     => 'neutron-db-manage --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugin.ini upgrade head',
+        :command     => 'neutron-db-manage  upgrade heads',
         :path        => '/usr/bin',
         :refreshonly => 'true',
-        :logoutput   => 'on_failure'
+        :try_sleep   => 5,
+        :tries       => 10,
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[neutron::install::end]',
+                         'Anchor[neutron::config::end]',
+                         'Anchor[neutron::dbsync::begin]'],
+        :notify      => 'Anchor[neutron::dbsync::end]',
       )
     end
 
@@ -22,10 +28,16 @@ describe 'neutron::db::sync' do
 
     it {
         is_expected.to contain_exec('neutron-db-sync').with(
-          :command     => 'neutron-db-manage --config-file /etc/neutron/neutron.conf upgrade head',
+          :command     => 'neutron-db-manage --config-file /etc/neutron/neutron.conf upgrade heads',
           :path        => '/usr/bin',
           :refreshonly => 'true',
-          :logoutput   => 'on_failure'
+          :try_sleep   => 5,
+          :tries       => 10,
+          :logoutput   => 'on_failure',
+          :subscribe   => ['Anchor[neutron::install::end]',
+                           'Anchor[neutron::config::end]',
+                           'Anchor[neutron::dbsync::begin]'],
+          :notify      => 'Anchor[neutron::dbsync::end]',
         )
     }
     end
