@@ -3,22 +3,20 @@ require 'spec_helper'
 describe 'neutron::server' do
 
   let :pre_condition do
-    "class { 'neutron': rabbit_password => 'passw0rd' }"
+    "class { 'neutron': rabbit_password => 'passw0rd' }
+     class { '::neutron::keystone::authtoken':
+       password => 'passw0rd',
+     }"
   end
 
   let :params do
-    { :password            => 'passw0rd',
-      :username            => 'neutron',
-      :keystone_auth_type  => 'password',
-      :project_domain_name => 'Default',
-      :project_name        => 'services',
-      :user_domain_name    => 'Default'}
+    {}
   end
 
   let :default_params do
     { :package_ensure                   => 'present',
       :enabled                          => true,
-      :auth_type                        => 'keystone',
+      :auth_strategy                    => 'keystone',
       :database_connection              => 'sqlite:////var/lib/neutron/ovs.sqlite',
       :database_max_retries             => 10,
       :database_idle_timeout            => 3600,
@@ -74,14 +72,12 @@ describe 'neutron::server' do
       is_expected.to contain_service('neutron-server').that_notifies('Anchor[neutron::service::end]')
       is_expected.not_to contain_class('neutron::db::sync')
       is_expected.to contain_service('neutron-server').with_name('neutron-server')
-      is_expected.to contain_neutron_config('DEFAULT/api_workers').with_value(facts[:processorcount])
-      is_expected.to contain_neutron_config('DEFAULT/rpc_workers').with_value(facts[:processorcount])
+      is_expected.to contain_neutron_config('DEFAULT/api_workers').with_value(facts[:os_workers])
+      is_expected.to contain_neutron_config('DEFAULT/rpc_workers').with_value(facts[:os_workers])
       is_expected.to contain_neutron_config('DEFAULT/agent_down_time').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/enable_new_agents').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/router_scheduler_driver').with_value(p[:router_scheduler_driver])
       is_expected.to contain_neutron_config('qos/notification_drivers').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_middleware/enable_proxy_headers_parsing').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('<SERVICE DEFAULT>')
     end
 
     context 'with manage_service as false' do
@@ -228,21 +224,6 @@ describe 'neutron::server' do
 
       it { is_expected.to contain_neutron_config('oslo_middleware/enable_proxy_headers_parsing').with_value(true) }
     end
-
-    context 'with ovs_integration_bridge set' do
-      before :each do
-	params.merge!({:ovs_integration_bridge => 'br-int' })
-      end
-
-      it { is_expected.to contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('br-int') }
-    end
-  end
-
-  shared_examples_for 'a neutron server with broken authentication' do
-    before do
-      params.delete(:password)
-    end
-    it_raises 'a Puppet::Error', /Please set password for neutron service user/
   end
 
   shared_examples_for 'VPNaaS, FWaaS and LBaaS package installation' do
@@ -274,8 +255,7 @@ describe 'neutron::server' do
   context 'on Debian platforms' do
     let :facts do
       @default_facts.merge(test_facts.merge({
-         :osfamily => 'Debian',
-         :processorcount => '2'
+         :osfamily       => 'Debian',
       }))
     end
 
@@ -285,7 +265,6 @@ describe 'neutron::server' do
     end
 
     it_configures 'a neutron server'
-    it_configures 'a neutron server with broken authentication'
     it_configures 'a neutron server without database synchronization'
   end
 
@@ -294,7 +273,6 @@ describe 'neutron::server' do
       @default_facts.merge(test_facts.merge({
           :osfamily               => 'RedHat',
           :operatingsystemrelease => '7',
-          :processorcount         => '2'
       }))
     end
 
@@ -303,7 +281,6 @@ describe 'neutron::server' do
     end
 
     it_configures 'a neutron server'
-    it_configures 'a neutron server with broken authentication'
     it_configures 'a neutron server without database synchronization'
   end
 end
